import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import { fromEvent, of, from } from 'rxjs';
import { switchMap, catchError, map } from 'rxjs/operators';

class IonicNetworkReachabilityService {
    // constructor() { }
    /**
     * @description it is used to ensure network connectivity
     * @param url `http-url-endpoint`
     * @returns return Promise<boolean> `true` or `false`, indicating network state
     */
    async isReachable(url = 'https://httpbin.org/') {
        try {
            const result = await fetch(url);
            if (result.ok) {
                return true;
            }
            else {
                return false;
            }
        }
        catch (error) {
            return false;
        }
    }
    /**
     * @description Get notified when the device goes offline
     * @param url `http-url-endpoint`
     * @returns Returns an Observable
     */
    onConnect(url = 'https://httpbin.org/') {
        return fromEvent(window, 'online').pipe(switchMap(() => {
            return this.httpReq(url).pipe(catchError(() => {
                return of({
                    ok: false,
                });
            }));
        }), map((networkResult) => {
            if (networkResult.ok) {
                return true;
            }
            else {
                return false;
            }
        }));
    }
    /**
     * @description Get notified when the device goes offline
     * @returns returns an Observable
     */
    onDisconnect() {
        return fromEvent(window, 'offline').pipe(map(() => 'you are offline'));
    }
    httpReq(url) {
        return from(fetch(url));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.11", ngImport: i0, type: IonicNetworkReachabilityService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.11", ngImport: i0, type: IonicNetworkReachabilityService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.11", ngImport: i0, type: IonicNetworkReachabilityService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/*
 * Public API Surface of ionic-network-reachability
 */

/**
 * Generated bundle index. Do not edit.
 */

export { IonicNetworkReachabilityService };
//# sourceMappingURL=ionic-network-reachability.mjs.map
